@@ -4,17 +4,18 @@
 let the developer test the snapshot tool in the source directory
 """
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2020, UChicago Argonne, LLC
+# :copyright: (c) 2017-2021, UChicago Argonne, LLC
 #
 # Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 import sys
+
 sys.path.insert(0, "..")
 
 import apstools.snapshot
@@ -25,10 +26,10 @@ developer_config_candidates = [
     "mongodb_poof",
     "mongodb_ookhd",
     "mongodb_localhost",
-    ]
+]
 
 if __name__ == "__main__":
-    ext =  ".yml"
+    ext = ".yml"
     for config in developer_config_candidates:
         print("Trying mongodb configuration: " + config + ext)
         try:
@@ -38,4 +39,6 @@ if __name__ == "__main__":
             print("Mongodb configuration file not found: " + config + ext)
             print(exc)
         except ServerSelectionTimeoutError:
-            print("Connection timeout with mongodb server: " + config + ext)
+            print(
+                "Connection timeout with mongodb server: " + config + ext
+            )
