@@ -13,7 +13,7 @@ Public Structures
 # -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2020, UChicago Argonne, LLC
+# :copyright: (c) 2017-2021, UChicago Argonne, LLC
 #
 # Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
 #
@@ -23,7 +23,9 @@ Public Structures
 from ophyd import Component, Device, EpicsSignalRO, Signal
 
 
-__all__ = ["IocStatsDevice", ]
+__all__ = [
+    "IocStatsDevice",
+]
 
 
 class IocStatsDevice(Device):
