@@ -14,6 +14,8 @@ Various utilities
    ~ExcelDatabaseFileGeneric
    ~ExcelReadError
    ~full_dotted_name
+   ~getDatabase
+   ~getDefaultDatabase
    ~ipython_profile_name
    ~itemizer
    ~json_export
@@ -23,7 +25,6 @@ Various utilities
    ~listruns
    ~object_explorer
    ~pairwise
-   ~plot_prune_fifo
    ~print_snapshot_list
    ~print_RE_md
    ~quantify_md_key_use
@@ -34,7 +35,6 @@ Various utilities
    ~safe_ophyd_name
    ~select_live_plot
    ~select_mpl_figure
-   ~show_ophyd_symbols
    ~split_quoted_line
    ~summarize_runs
    ~text_encode
@@ -46,30 +46,32 @@ Various utilities
 
 """
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # :author:    Pete R. Jemian
 # :email:     jemian@anl.gov
-# :copyright: (c) 2017-2020, UChicago Argonne, LLC
+# :copyright: (c) 2017-2021, UChicago Argonne, LLC
 #
 # Distributed under the terms of the Creative Commons Attribution 4.0 International Public License.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
-from bluesky.callbacks.best_effort import BestEffortCallback
 from bluesky import plan_stubs as bps
-from collections import defaultdict, OrderedDict
+from bluesky.callbacks.best_effort import BestEffortCallback
+from collections import defaultdict
+from collections import OrderedDict
+from email.mime.text import MIMEText
+from event_model import NumpyEncoder
 import databroker
 import databroker.queries
 import datetime
-from email.mime.text import MIMEText
-from event_model import NumpyEncoder
 import json
 import logging
 import math
+import openpyxl
+import openpyxl.utils.exceptions
 import ophyd
 import os
-import pandas
 import psutil
 import pyRestTable
 import re
@@ -79,7 +81,6 @@ import sys
 import threading
 import time
 import warnings
-import xlrd
 import zipfile
 
 from .filewriters import _rebuild_scan_command
@@ -90,7 +91,8 @@ logger = logging.getLogger(__name__)
 MAX_EPICS_STRINGOUT_LENGTH = 40
 
 
-class ExcelReadError(xlrd.XLRDError): ...
+class ExcelReadError(openpyxl.utils.exceptions.InvalidFileException):
+    ...
 
 
 def cleanupText(text):
@@ -119,7 +121,7 @@ def command_list_as_table(commands, show_raw=False):
     tbl.addLabel("line #")
     tbl.addLabel("action")
     tbl.addLabel("parameters")
-    if show_raw:        # only the developer might use this
+    if show_raw:  # only the developer might use this
         tbl.addLabel("raw input")
     for command in commands:
         action, args, line_number, raw_command = command
@@ -130,20 +132,33 @@ def command_list_as_table(commands, show_raw=False):
     return tbl
 
 
-def device_read2table(device, show_ancient=True, use_datetime=True, printing=True):
+def device_read2table(
+    # fmt:off
+    device, show_ancient=True, use_datetime=True, printing=True
+    # fmt:on
+):
     """
     DEPRECATED: Use listdevice() instead.
     """
     warnings.warn(
         "DEPRECATED: device_read2table() will be removed"
         " in a future release.  Use listdevice() instead."
-        )
-    listdevice(device, show_ancient=show_ancient, use_datetime=use_datetime, printing=printing)
+    )
+    listdevice(
+        device,
+        show_ancient=show_ancient,
+        use_datetime=use_datetime,
+        printing=printing,
+    )
 
 
-def listdevice(device, show_ancient=True, use_datetime=True, printing=True):
+def listdevice(
+    # fmt:off
+    device, show_ancient=True, use_datetime=True, printing=True
+    # fmt:on
+):
     """
-    read an ophyd device and return a pyRestTable Table
+    Read an ophyd device and return a pyRestTable Table.
 
     Include an option to suppress ancient values identified
     by timestamp from 1989.  These are values only defined in
@@ -230,7 +245,7 @@ def full_dotted_name(obj):
         names.append(obj.attr_name)
         obj = obj.parent
     names.append(obj.name)
-    return '.'.join(names[::-1])
+    return ".".join(names[::-1])
 
 
 def _get_named_child(obj, nm):
@@ -255,22 +270,128 @@ def _get_pv(obj):
         return obj.prefix
 
 
+def getDatabase(db=None, catalog_name=None):
+    """
+    Return Bluesky database using keyword guides or default choice.
+
+    PARAMETERS
+
+    db
+        *object* :
+        Instance of databroker v1 ``Broker`` or
+        v2 ``BlueskyMongoCatalog``.
+        (default: see ``catalog_name`` keyword argument)
+    catalog_name
+        *str* :
+        Name of databroker v2 catalog, used when supplied
+        ``db`` is ``None``.
+        (default: catalog with most recent run timestamp)
+
+    RETURNS
+
+    object or ``None``:
+        Bluesky database, an instance of ``databroker.catalog``
+
+    (new in release 1.4.0)
+    """
+    if not hasattr(db, "v2"):
+        if (
+            hasattr(catalog_name, "name")
+            and catalog_name in databroker.catalog
+        ):
+            # in case a catalog was passed as catalog_name
+            db = catalog_name
+        elif catalog_name is None:
+            db = getDefaultDatabase()
+        else:
+            db = databroker.catalog[catalog_name]
+    return db.v2
+
+
+def getDefaultDatabase():
+    """
+    Find the "default" database (has the most recent run).
+
+    Note that here, *database* and *catalog* mean the same.
+
+    This routine looks at all the database instances defined in the
+    current session (console or notebook).  If there is only one or no
+    database instances defined as objects in the current session, the
+    choice is simple.  When there is more than one database instance in
+    the current session, then the one with the most recent run timestamp
+    is selected.  In the case (as happens when starting with a new
+    database) that the current database has **no** runs *and* another
+    database instance is defined in the session *and* that additional
+    database has runs in it (such as the previous database), then the
+    database with the newest run timestamp (and not the newer empty
+    database) will be chosen.
+
+    RETURNS
+
+    object or ``None``:
+        Bluesky database, an instance of ``databroker.catalog``
+
+    (new in release 1.4.0)
+    """
+    # look through the console namespace
+    g = ipython_shell_namespace()
+    if len(g) == 0:
+        # ultimate fallback
+        g = globals()
+
+    # note all database instances in memory
+    db_list = []
+    for k, v in g.items():
+        if hasattr(v, "__class__") and not k.startswith("_"):
+            end = v.__class__.__name__.split(".")[-1]
+            if end in ("Broker", "BlueskyMongoCatalog"):
+                db_list.append(v)
+
+    # easy decisions first
+    if len(db_list) == 0:
+        return None
+    if len(db_list) == 1:
+        return db_list[0]
+
+    # get the most recent run from each
+    time_ref = {}
+    for cat_name in list(databroker.catalog):
+        cat = databroker.catalog[cat_name]
+        if cat in db_list:
+            print(cat_name, cat.name)
+            if len(cat) > 0:
+                run = cat.v2[-1]
+                t = run.metadata["start"]["time"]
+            else:
+                t = 0
+            time_ref[cat_name] = t, cat
+
+    # pick the highest number for time
+    highest = max([v[0] for v in time_ref.values()])
+    choices = [v[1] for v in time_ref.values() if v[0] == highest]
+    if len(choices) == 0:
+        return None
+    # return the catalog with the most recent timestamp
+    return sorted(choices)[-1]
+
+
 def itemizer(fmt, items):
     """Format a list of items."""
     return [fmt % k for k in items]
 
 
 def listruns(
-        num=20,
-        keys=None,
-        printing=True,
-        show_command=True,
-        db=None,
-        catalog_name=None,
-        exit_status=None,
-        since=None,
-        until=None,
-        **db_search_terms):
+    num=20,
+    keys=None,
+    printing=True,
+    show_command=True,
+    db=None,
+    catalog_name=None,
+    exit_status=None,
+    since=None,
+    until=None,
+    **db_search_terms,
+):
     """
     make a table of the most recent runs (scans)
 
@@ -297,12 +418,14 @@ def listruns(
         (default: ``True``)
     db
         *object* :
-        Instance of databroker v1 ``Broker`` or v2 ``catalog``
+        Instance of databroker v1 ``Broker`` or
+        v2 ``BlueskyMongoCatalog``.
         (default: see ``catalog_name`` keyword argument)
     catalog_name
         *str* :
-        Name of databroker v2 catalog, used when supplied ``db`` is ``None``.
-        (default: ``mongodb_config``)
+        Name of databroker v2 catalog, used when the supplied
+        ``db`` is ``None``.
+        (default: catalog with most recent run timestamp)
         (new in release 1.3.0)
     since
         *str* :
@@ -356,8 +479,7 @@ def listruns(
 
     *new in apstools release 1.1.10*
     """
-    catalog_name = catalog_name or "mongodb_config"
-    db = (db or databroker.catalog[catalog_name]).v2
+    db = getDatabase(db=db, catalog_name=catalog_name)
     keys = keys or []
     num_runs_requested = min(abs(num), len(db))
     since = since or "1995-01-01"
@@ -384,30 +506,33 @@ def listruns(
         if stop is not None:
             reported_exit_status = stop.get("exit_status", "")
 
-        if (exit_status is not None
-            and reported_exit_status != exit_status):
+        if exit_status is not None and reported_exit_status != exit_status:
             continue
 
         row = [
             start["uid"][:7],
-            datetime.datetime.fromtimestamp(start['time']),
+            datetime.datetime.fromtimestamp(start["time"]),
             reported_exit_status,
-            ]
+        ]
 
         for k in labels:
             if k == "command":
                 command = _rebuild_scan_command(start)
+                # fmt: off
                 command = command[command.find(" "):].strip()
+                # fmt: on
                 maxlen = 40
                 if len(command) > maxlen:
                     suffix = " ..."
-                    command = command[:maxlen-len(suffix)] + suffix
+                    command = command[: maxlen - len(suffix)] + suffix
                 row.append(command)
             else:
                 row.append(start.get(k, ""))
         table.addRow(row)
 
     if printing:
+        if db.name is not None:
+            print(f"catalog name: {db.name}")
         print(table)
     return table
 
@@ -435,7 +560,7 @@ def _ophyd_structure_walker(obj):
         return items
 
 
-def object_explorer(obj, sortby=None, fmt='simple', printing=True):
+def object_explorer(obj, sortby=None, fmt="simple", printing=True):
     """
     print the contents of obj
     """
@@ -453,9 +578,8 @@ def object_explorer(obj, sortby=None, fmt='simple', printing=True):
             key = _get_pv(obj) or "--"
         else:
             raise ValueError(
-                "sortby should be None or 'PV'"
-                f" found sortby='{sortby}'"
-                )
+                f"sortby should be None or 'PV', found sortby='{sortby}'"
+            )
         return key
 
     for item in sorted(items, key=sorter):
@@ -501,11 +625,11 @@ def print_RE_md(dictionary=None, fmt="simple", printing=True):
 
     """
     # override noting that fmt="markdown" will not display correctly
-    fmt="simple"
+    fmt = "simple"
 
     dictionary = dictionary or ipython_shell_namespace()["RE"].md
-    md = dict(dictionary)   # copy of input for editing
-    v = dictionary_table(md["versions"])   # sub-table
+    md = dict(dictionary)  # copy of input for editing
+    v = dictionary_table(md["versions"])  # sub-table
     md["versions"] = v.reST(fmt=fmt).rstrip()
     table = dictionary_table(md)
     if printing:
@@ -520,14 +644,14 @@ def pairwise(iterable):
 
     ::
 
-		s -> (s0, s1), (s2, s3), (s4, s5), ...
+        s -> (s0, s1), (s2, s3), (s4, s5), ...
 
-		In [71]: for item in pairwise("a b c d e fg".split()):
-			...:     print(item)
-			...:
-		('a', 'b')
-		('c', 'd')
-		('e', 'fg')
+        In [71]: for item in pairwise("a b c d e fg".split()):
+            ...:     print(item)
+            ...:
+        ('a', 'b')
+        ('c', 'd')
+        ('e', 'fg')
 
     """
     a = iter(iterable)
@@ -548,8 +672,9 @@ def replay(headers, callback=None, sort=True):
 
     callback
         *scan* or *[scan]* :
-        The Bluesky callback to handle the stream of documents from a scan.
-        If ``None``, then use the `bec` (BestEffortCallback) from the IPython shell.
+        The Bluesky callback to handle the stream of documents from a
+        scan. If ``None``, then use the `bec` (BestEffortCallback) from
+        the IPython shell.
         (default:``None``)
 
     sort
@@ -560,10 +685,10 @@ def replay(headers, callback=None, sort=True):
     *new in apstools release 1.1.11*
     """
     callback = callback or ipython_shell_namespace().get(
-        "bec",                  # get from IPython shell
-        BestEffortCallback(),   # make one, if we must
-        )
-    _headers = headers   # do not mutate the input arg
+        "bec",  # get from IPython shell
+        BestEffortCallback(),  # make one, if we must
+    )
+    _headers = headers  # do not mutate the input arg
     if isinstance(_headers, databroker.Header):
         _headers = [_headers]
 
@@ -574,22 +699,25 @@ def replay(headers, callback=None, sort=True):
         """Default for databroker v0 results."""
         return -run.start["time"]
 
+    # fmt: off
     sorter = {
         True: increasing_time_sorter,
-        False: decreasing_time_sorter
-        }[sort]
+        False: decreasing_time_sorter,
+    }[sort]
+    # fmt: on
 
     for h in sorted(_headers, key=sorter):
         if not isinstance(h, databroker.Header):
             raise TypeError(
-                f"Must be a databroker Header: received: {type(h)}: |{h}|"
+                "Must be a databroker Header:"
+                f" received: {type(h)}: |{h}|"
             )
         cmd = _rebuild_scan_command(h.start)
         logger.debug("%s", cmd)
 
         # at last, this is where the real action happens
-        for k, doc in h.documents():    # get the stream
-            callback(k, doc)            # play it through the callback
+        for k, doc in h.documents():  # get the stream
+            callback(k, doc)  # play it through the callback
 
 
 def rss_mem():
@@ -613,15 +741,17 @@ def run_in_thread(func):
        #...
 
     """
+
     def wrapper(*args, **kwargs):
         thread = threading.Thread(target=func, args=args, kwargs=kwargs)
         thread.start()
         return thread
+
     return wrapper
 
 
 def safe_ophyd_name(text):
-    """
+    r"""
     make text safe to be used as an ophyd object name
 
     Given some input text string, return a clean version.
@@ -634,8 +764,8 @@ def safe_ophyd_name(text):
 
     Also can be used for safe HDF5 and NeXus names.
     """
-    replacement = '_'
-    noncompliance = '[^\w_]'
+    replacement = "_"
+    noncompliance = r"[^\w_]"
 
     # replace ALL non-compliances with '_'
     safer = replacement.join(re.split(noncompliance, text))
@@ -728,31 +858,13 @@ def listobjects(show_pv=True, printing=True, verbose=False, symbols=None):
                     row.append("")
             if verbose:
                 row.append(str(v))
-            row.append(' '.join(v._ophyd_labels_))
+            row.append(" ".join(v._ophyd_labels_))
             table.addRow(row)
     if printing:
         print(table)
     return table
 
 
-def show_ophyd_symbols(show_pv=True,
-                       printing=True,
-                       verbose=False,
-                       symbols=None):
-    """
-    DEPRECATED: Use listobjects() instead.
-    """
-    warnings.warn(
-        "DEPRECATED: show_ophyd_symbols() will be removed"
-        " in a future release.  Use listobjects() instead."
-        )
-    listobjects(
-        show_pv=show_pv,
-        printing=printing,
-        verbose=verbose,
-        symbols=symbols)
-
-
 def split_quoted_line(line):
     """
     splits a line into words some of which might be quoted
@@ -780,7 +892,7 @@ def split_quoted_line(line):
     quoted = False
     multi = None
     for p in line.split():
-        if not quoted and p.startswith('"'):   # begin quoted text
+        if not quoted and p.startswith('"'):  # begin quoted text
             quoted = True
             multi = ""
 
@@ -788,12 +900,12 @@ def split_quoted_line(line):
             if len(multi) > 0:
                 multi += " "
             multi += p
-            if p.endswith('"'):     # end quoted text
+            if p.endswith('"'):  # end quoted text
                 quoted = False
 
         if not quoted:
             if multi is not None:
-                parts.append(multi[1:-1])   # remove enclosing quotes
+                parts.append(multi[1:-1])  # remove enclosing quotes
                 multi = None
             else:
                 parts.append(p)
@@ -814,23 +926,30 @@ def summarize_runs(since=None, db=None):
 
     since
         *str* :
-        Report all runs since this ISO8601 date & time (default: ``1995``)
+        Report all runs since this ISO8601 date & time
+        (default: ``1995``)
     db
         *object* :
         Instance of ``databroker.Broker()``
         (default: ``db`` from the IPython shell)
     """
     db = db or ipython_shell_namespace()["db"]
-    since = since or "1995"     # no APS X-ray experiment data before 1995!
+    # no APS X-ray experiment data before 1995!
+    since = since or "1995"
     cat = db.v2.search(databroker.queries.TimeRange(since=since))
     plans = defaultdict(list)
     t0 = time.time()
     for n, uid in enumerate(cat):
         t1 = time.time()
-        run = cat[uid]      # this step is very slow (0.01 - 0.5 seconds each!)
+        # next step is very slow (0.01 - 0.5 seconds each!)
+        run = cat[uid]
         t2 = time.time()
         plan_name = run.metadata["start"].get("plan_name", "unknown")
-        dt = datetime.datetime.fromtimestamp(run.metadata["start"]["time"]).isoformat()
+        # fmt:off
+        dt = datetime.datetime.fromtimestamp(
+            run.metadata["start"]["time"]
+        ).isoformat()
+        # fmt:on
         scan_id = run.metadata["start"].get("scan_id", "unknown")
         plans[plan_name].append(
             dict(
@@ -845,10 +964,10 @@ def summarize_runs(since=None, db=None):
             "%s %s dt1=%4.01fus dt2=%5.01fms %s",
             scan_id,
             dt,
-            (t1-t0)*1e6,
-            (t2-t1)*1e3,
+            (t1 - t0) * 1e6,
+            (t2 - t1) * 1e3,
             plan_name,
-            )
+        )
         t0 = time.time()
 
     def sorter(plan_name):
@@ -858,16 +977,16 @@ def summarize_runs(since=None, db=None):
     table.labels = "plan quantity".split()
     for k in sorted(plans.keys(), key=sorter, reverse=True):
         table.addRow((k, sorter(k)))
-    table.addRow(("TOTAL", n+1))
+    table.addRow(("TOTAL", n + 1))
     print(table)
 
 
 def text_encode(source):
     """Encode ``source`` using the default codepoint."""
-    return source.encode(errors='ignore')
+    return source.encode(errors="ignore")
 
 
-def to_unicode_or_bust(obj, encoding='utf-8'):
+def to_unicode_or_bust(obj, encoding="utf-8"):
     """from: http://farmdev.com/talks/unicode/  ."""
     if isinstance(obj, str):
         if not isinstance(obj, str):
@@ -878,7 +997,7 @@ def to_unicode_or_bust(obj, encoding='utf-8'):
 def trim_string_for_EPICS(msg):
     """String must not exceed EPICS PV length."""
     if len(msg) > MAX_EPICS_STRINGOUT_LENGTH:
-        msg = msg[:MAX_EPICS_STRINGOUT_LENGTH-1]
+        msg = msg[: MAX_EPICS_STRINGOUT_LENGTH - 1]
     return msg
 
 
@@ -903,10 +1022,10 @@ def unix(command, raises=True):
     process = subprocess.Popen(
         command,
         shell=True,
-        stdin = subprocess.PIPE,
-        stdout = subprocess.PIPE,
-        stderr = subprocess.PIPE,
-        )
+        stdin=subprocess.PIPE,
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
 
     stdout, stderr = process.communicate()
 
@@ -921,7 +1040,7 @@ def unix(command, raises=True):
 
 def connect_pvlist(pvlist, wait=True, timeout=2, poll_interval=0.1):
     """
-    given a list of EPICS PV names, return a dictionary of EpicsSignal objects
+    Given list of EPICS PV names, return dict of EpicsSignal objects.
 
     PARAMETERS
 
@@ -930,13 +1049,16 @@ def connect_pvlist(pvlist, wait=True, timeout=2, poll_interval=0.1):
         list of EPICS PV names
     wait
         *bool* :
-        should wait for EpicsSignal objects to connect, default: ``True``
+        should wait for EpicsSignal objects to connect
+        (default: ``True``)
     timeout
         *float* :
-        maximum time to wait for PV connections, seconds, default: 2.0
+        maximum time to wait for PV connections, seconds
+        (default: 2.0)
     poll_interval
         *float* :
-        time to sleep between checks for PV connections, seconds, default: 0.1
+        time to sleep between checks for PV connections, seconds
+        (default: 0.1)
     """
     obj_dict = OrderedDict()
     for item in pvlist:
@@ -1015,9 +1137,9 @@ class EmailNotifications(object):
     def send(self, subject, message):
         """send ``message`` to all addresses"""
         msg = MIMEText(message)
-        msg['Subject'] = subject
-        msg['From'] = self.sender
-        msg['To'] = ",".join(self.addresses)
+        msg["Subject"] = subject
+        msg["From"] = self.sender
+        msg["To"] = ",".join(self.addresses)
         s = smtplib.SMTP(self.smtp_host)
         s.sendmail(self.sender, self.addresses, msg.as_string())
         s.quit()
@@ -1039,7 +1161,7 @@ class ExcelDatabaseFileBase(object):
 
         class ExhibitorsDB(ExcelDatabaseFileBase):
             '''
-            content for Exhibitors, vendors, and Sponsors from the Excel file
+            content for exhibitors from the Excel file
             '''
             EXCEL_FILE = os.path.join("resources", "exhibitors.xlsx")
             LABELS_ROW = 2
@@ -1049,15 +1171,15 @@ class ExcelDatabaseFileBase(object):
                 pass
 
             def handleExcelRowEntry(self, entry):
-                '''identify the unique key for this entry (row of the Excel file)'''
+                '''identify unique key (row of the Excel file)'''
                 key = entry["Name"]
                 self.db[key] = entry
 
     """
 
-    EXCEL_FILE = None       # subclass MUST define
+    EXCEL_FILE = None  # subclass MUST define
     # EXCEL_FILE = os.path.join("abstracts", "index of abstracts.xlsx")
-    LABELS_ROW = 3          # labels are on line LABELS_ROW+1 in the Excel file
+    LABELS_ROW = 3  # labels are on line LABELS_ROW+1 in the Excel file
 
     def __init__(self, ignore_extra=True):
         self.db = OrderedDict()
@@ -1070,39 +1192,52 @@ class ExcelDatabaseFileBase(object):
 
         self.parse(ignore_extra=ignore_extra)
 
-    def handle_single_entry(self, entry):       # subclass MUST override
-        raise NotImplementedError("subclass must override handle_single_entry() method")
+    def handle_single_entry(self, entry):  # subclass MUST override
+        raise NotImplementedError(
+            "subclass must override handle_single_entry() method"
+        )
 
-    def handleExcelRowEntry(self, entry):       # subclass MUST override
-        raise NotImplementedError("subclass must override handleExcelRowEntry() method")
+    def handleExcelRowEntry(self, entry):  # subclass MUST override
+        raise NotImplementedError(
+            "subclass must override handleExcelRowEntry() method"
+        )
 
-    def parse(self, labels_row_num=None, data_start_row_num=None, ignore_extra=True):
+    def parse(
+        self,
+        labels_row_num=None,
+        data_start_row_num=None,
+        ignore_extra=True,
+    ):
         labels_row_num = labels_row_num or self.LABELS_ROW
         try:
+            wb = openpyxl.load_workbook(self.fname)
+            ws = wb.worksheets[self.sheet_name]
             if ignore_extra:
                 # ignore data outside of table in spreadsheet file
-                nrows, ncols = self.getTableBoundaries(labels_row_num)
-                xl = pandas.read_excel(
-                    self.fname,
-                    sheet_name=self.sheet_name,
-                    skiprows=labels_row_num,
-                    usecols=range(ncols),
-                    nrows=nrows,
-                    )
+                data = list(ws.rows)[labels_row_num:]
+                self.data_labels = []
+                for c in data[0]:
+                    if c.value is None:
+                        break
+                    self.data_labels.append(c.value)
+                rows = []
+                for r in data[1:]:
+                    if r[0].value is None:
+                        break
+                    rows.append(r[: len(self.data_labels)])
             else:
-                xl = pandas.read_excel(
-                    self.fname,
-                    sheet_name=self.sheet_name,
-                    header=None,
-                    )
-        except xlrd.XLRDError as exc:
+                # use the whole sheet
+                rows = list(ws.rows)
+                # create the column titles
+                self.data_labels = [
+                    f"Column_{i+1}" for i in range(len(rows[0]))
+                ]
+        except openpyxl.utils.exceptions.InvalidFileException as exc:
             raise ExcelReadError(exc)
-        self.data_labels = list(map(str, xl.columns.values))
-        # unused: data_start_row_num = data_start_row_num or labels_row_num+1
-        for row_data in xl.values:
+        for row in rows:
             entry = OrderedDict()
             for _col, label in enumerate(self.data_labels):
-                entry[label] = self._getExcelColumnValue(row_data, _col)
+                entry[label] = row[_col].value
                 self.handle_single_entry(entry)
             self.handleExcelRowEntry(entry)
 
@@ -1121,29 +1256,6 @@ class ExcelDatabaseFileBase(object):
             return False
         return math.isnan(value)
 
-    def getTableBoundaries(self, labels_row_num=None):
-        """
-        identify how many rows and columns are in the Excel spreadsheet table
-        """
-        labels_row_num = labels_row_num or self.LABELS_ROW
-        xl = pandas.read_excel(self.fname, sheet_name=self.sheet_name, skiprows=labels_row_num)
-
-        ncols = len(xl.columns)
-        for i, k in enumerate(xl.columns):
-            if k.startswith(f"Unnamed: {i}"):
-                # TODO: verify all values under this label are NaN
-                ncols = i
-                break
-
-        nrows = len(xl.values)
-        for j, r in enumerate(xl.values):
-            r = r[:ncols]
-            if False not in [self._isExcel_nan(value) for value in r]:
-                nrows = j
-                break
-
-        return nrows, ncols
-
 
 class ExcelDatabaseFileGeneric(ExcelDatabaseFileBase):
     """
@@ -1153,31 +1265,35 @@ class ExcelDatabaseFileGeneric(ExcelDatabaseFileBase):
 
     .. note:: This is the class to use when reading Excel spreadsheets.
 
-    In the spreadsheet, the first sheet should contain the table to be used.
-    By default (see keyword parameter ``labels_row``), the table should start
-    in cell A4.  The column labels are given in row 4.  A blank column
-    should appear to the right of the table (see keyword parameter ``ignore_extra``).
-    The column labels will describe the action and its parameters.  Additional
-    columns may be added for metadata or other purposes.
-    The rows below the column labels should contain actions and parameters
-    for those actions, one action per row.
+    In the spreadsheet, the first sheet should contain the table to be
+    used. By default (see keyword parameter ``labels_row``), the table
+    should start in cell A4.  The column labels are given in row 4.  A
+    blank column should appear to the right of the table (see keyword
+    parameter ``ignore_extra``). The column labels will describe the
+    action and its parameters.  Additional columns may be added for
+    metadata or other purposes.
+
+    The rows below the column labels should contain actions and
+    parameters for those actions, one action per row.
+
     To make a comment, place a ``#`` in the action column.  A comment
-    should be ignored by the bluesky plan that reads this table.
-    The table will end with a row of empty cells.
+    should be ignored by the bluesky plan that reads this table. The
+    table will end with a row of empty cells.
 
-    While it's a good idea to put the ``action`` column first, that is not necessary.
-    It is not even necessary to name the column ``action``.
-    You can re-arrange the order of the columns and change their names
-    **as long as** the column names match
-    what text strings your Python code expects to find.
+    While it's a good idea to put the ``action`` column first, that is
+    not necessary. It is not even necessary to name the column
+    ``action``. You can re-arrange the order of the columns and change
+    their names **as long as** the column names match what text strings
+    your Python code expects to find.
 
-    A future upgrade [#]_ will allow the table boundaries to be
-    named by Excel when using Excel's ``Format as Table`` [#]_ feature.
-    For now, leave a blank row and column at the bottom and right
-    edges of the table.
+    A future upgrade [#]_ will allow the table boundaries to be named by
+    Excel when using Excel's ``Format as Table`` [#]_ feature. For now,
+    leave a blank row and column at the bottom and right edges of the
+    table.
 
     .. [#] https://github.com/BCDA-APS/apstools/issues/122
-    .. [#] Excel's ``Format as Table``: https://support.office.com/en-us/article/Format-an-Excel-table-6789619F-C889-495C-99C2-2F971C0E2370
+    .. [#] Excel's ``Format as Table``:
+        https://support.office.com/en-us/article/Format-an-Excel-table-6789619F-C889-495C-99C2-2F971C0E2370
 
     PARAMETERS
 
@@ -1190,8 +1306,8 @@ class ExcelDatabaseFileGeneric(ExcelDatabaseFileBase):
         default: ``3`` (Excel row 4)
     ignore_extra
         *bool* :
-        When ``True``, ignore any cells outside of the table,
-        default: ``True``
+        When ``True``, ignore any cells outside of the table, default:
+        ``True``.
 
         Note that when ``True``, a row of cells *within* the table will
         be recognized as the end of the table, even if there are
@@ -1205,8 +1321,9 @@ class ExcelDatabaseFileGeneric(ExcelDatabaseFileBase):
 
     See section :ref:`example_run_command_file` for more examples.
 
-    (See also :ref:`example screen shot <excel_plan_spreadsheet_screen>`.)
-    Table (on Sheet 1) begins on row 4 in first column::
+    (See also :ref:`example screen shot
+    <excel_plan_spreadsheet_screen>`.) Table (on Sheet 1) begins on row
+    4 in first column::
 
         1  |  some text here, maybe a title
         2  |  (could have content here)
@@ -1286,6 +1403,7 @@ def ipython_profile_name():
 
     """
     from IPython import get_ipython
+
     return get_ipython().profile
 
 
@@ -1295,84 +1413,13 @@ def ipython_shell_namespace():
     """
     try:
         from IPython import get_ipython
+
         ns = get_ipython().user_ns
     except AttributeError:
         ns = {}
     return ns
 
 
-def plot_prune_fifo(bec, n, y, x):
-    """
-    find the plot with axes x and y and replot with only the last *n* lines
-
-    Note: this is not a bluesky plan.  Call it as normal Python function.
-
-    EXAMPLE::
-
-        plot_prune_fifo(bec, 1, noisy, m1)
-
-    PARAMETERS
-
-    bec
-        *object* :
-        instance of BestEffortCallback
-
-    n
-        *int* :
-        number of plots to keep
-
-    y
-        *object* :
-        instance of ophyd.Signal (or subclass),
-        dependent (y) axis
-
-    x
-        *object* :
-        instance of ophyd.Signal (or subclass),
-        independent (x) axis
-
-    DEPRECATED: Will be removed by end of 2020-12.
-    Use :func:`trim_plot_lines` instead.
-    Note the order of parameters is different in :func:`trim_plot_lines`.
-    """
-    warnings.warn(
-        "DEPRECATED: plot_prune_fifo() will be removed"
-        " in a future release.  Use trim_plot_lines() instead."
-        "  Note the order of parameters is different in trim_plot_lines()."
-        )
-
-    if n < 0:
-        raise ValueError(
-            "must be zero or greater",
-            f" received {n}")
-
-    for liveplot in bec._live_plots.values():
-        lp = liveplot.get(y.name)
-        if lp is None:
-            logger.debug(f"no LivePlot with name {y.name}")
-            continue
-        if lp.x != x.name or lp.y != y.name:
-            logger.debug(f"no LivePlot with axes ('{x.name}', '{y.name}')")
-            continue
-
-        # pick out only the traces that contain plot data
-        # skipping the lines that show peak centers
-        lines = [
-            tr
-            for tr in lp.ax.lines
-            if len(tr._x) != 2
-                or len(tr._y) != 2
-                or (len(tr._x) == 2 and tr._x[0] != tr._x[1])
-        ]
-        if len(lines) > n:
-            logger.debug(f"limiting LivePlot({y.name}) to {n} traces")
-            lp.ax.lines = lines[-n:]
-            lp.ax.legend()
-            if n > 0:
-                lp.update_plot()
-        return lp
-
-
 def select_mpl_figure(x, y):
     """
     get the MatPlotLib Figure window for y vs x
@@ -1392,6 +1439,7 @@ def select_mpl_figure(x, y):
         Instance of ``matplotlib.pyplot.Figure()``
     """
     import matplotlib.pyplot as plt
+
     figure_name = f"{y.name} vs {x.name}"
     if figure_name in plt.get_figlabels():
         return plt.figure(figure_name)
@@ -1426,7 +1474,8 @@ def trim_plot_lines(bec, n, x, y):
     """
     find the plot with axes x and y and replot with at most the last *n* lines
 
-    Note: :func:`trim_plot_lines` is not a bluesky plan.  Call it as normal Python function.
+    Note: :func:`trim_plot_lines` is not a bluesky plan.  Call it as
+    normal Python function.
 
     EXAMPLE::
 
@@ -1452,7 +1501,7 @@ def trim_plot_lines(bec, n, x, y):
         instance of ophyd.Signal (or subclass),
         dependent (y) axis
 
-    (new in release 1.3.5, replaces :func:`plot_prune_fifo`)
+    (new in release 1.3.5)
     """
     liveplot = select_live_plot(bec, y)
     if liveplot is None:
@@ -1475,7 +1524,10 @@ def trim_plot_lines(bec, n, x, y):
             if not str(exc).endswith("x not in list"):
                 logger.warning(
                     "%s vs %s: mpl remove() error: %s",
-                    y.name, x.name, str(exc))
+                    y.name,
+                    x.name,
+                    str(exc),
+                )
     ax.legend()
     liveplot.update_plot()
     logger.debug("trim complete")
@@ -1645,7 +1697,8 @@ def json_export(headers, filename, zipfilename=None):
 
     headers
         *[headers]* or ``databroker._core.Results`` object :
-        list of databroker headers as returned from ``db(...search criteria...)``
+        list of databroker headers as returned from
+        ``db(...search criteria...)``
     filename
         *str* :
         name of file into which to write JSON
@@ -1738,7 +1791,14 @@ def redefine_motor_position(motor, new_position):
     yield from bps.mv(motor.set_use_switch, 0)
 
 
-def quantify_md_key_use(key=None, db=None, catalog_name=None, since=None, until=None, query=None):
+def quantify_md_key_use(
+    key=None,
+    db=None,
+    catalog_name=None,
+    since=None,
+    until=None,
+    query=None,
+):
     """
     print table of different ``key`` values and how many times each appears
 
@@ -1784,19 +1844,21 @@ def quantify_md_key_use(key=None, db=None, catalog_name=None, since=None, until=
         quantify_md_key_use(catalog_name="8id", since="2020-01", until="2020-03")
 
     """
-    key = key or 'plan_name'
-    catalog_name = catalog_name or 'mongodb_config'
+    key = key or "plan_name"
+    catalog_name = catalog_name or "mongodb_config"
     query = query or {}
     since = since or "1995-01-01"
     until = until or "2100-12-31"
 
-    cat = (db or databroker.catalog[catalog_name]).v2.search(
-        databroker.queries.TimeRange(since=since, until=until)
-    ).search(query)
+    cat = (
+        (db or databroker.catalog[catalog_name])
+        .v2.search(databroker.queries.TimeRange(since=since, until=until))
+        .search(query)
+    )
 
     items = []
     while True:
-        runs = cat.search({key:{'$exists': True, '$nin': items}})
+        runs = cat.search({key: {"$exists": True, "$nin": items}})
         if len(runs) == 0:
             break
         else:
@@ -1843,6 +1905,8 @@ def copy_filtered_catalog(source_cat, target_cat, query=None):
     query = query or {}
     for i, uid in enumerate(source_cat.v2.search(query)):
         run = source_cat.v1[uid]
-        logger.debug("%d  %s  #docs=%d", i+1, uid, len(list(run.documents())))
+        logger.debug(
+            "%d  %s  #docs=%d", i + 1, uid, len(list(run.documents()))
+        )
         for key, doc in run.documents():
             target_cat.v1.insert(key, doc)
